@@ -22,7 +22,7 @@ def bye_function(_request):
 def hello_function(request):
     wp = jp.WebPage()
     wp.add(jp.P(text='Hello there!', classes='text-5xl m-2'))
-    print("request  = ", request.url_for("hello"))
+    #print("request  = ", request.url_for("hello"))
     return wp
 
 class TestRouteAndUrlFor(Basetest):
