@@ -3,10 +3,10 @@ Created on 2022-08-25
 
 @author: wf
 '''
+import asyncio
 from selenium import webdriver
 from selenium.webdriver.common.by import By
 import justpy as jp
-import time
 
 from tests.basetest import BaseAsynctest, Basetest
 #from webdriver_manager.firefox import GeckoDriverManager
@@ -14,7 +14,7 @@ from tests.basetest import BaseAsynctest, Basetest
 from selenium.webdriver.chrome.options import Options
 from selenium.webdriver.chrome.service import Service as ChromeService
 from webdriver_manager.chrome import ChromeDriverManager
-import os
+#import os
 
 class TestWithSelenium(BaseAsynctest):
     '''
@@ -35,6 +35,9 @@ class TestWithSelenium(BaseAsynctest):
         self.browser = webdriver.Chrome(service=ChromeService(chrome_executable),chrome_options=chrome_options)
 
     async def onDivClick(self, msg):
+        '''
+        handle the click of the div
+        '''
         print(msg)
         self.clickCount+=1
         msg.target.text= f'I was clicked {self.clickCount} times'
@@ -56,19 +59,20 @@ class TestWithSelenium(BaseAsynctest):
         '''
         # do not run automatically in CI yet 
         # need to fix 
-        #if Basetest.inPublicCI():
-        #    return
+        if Basetest.inPublicCI():
+            return
+        await asyncio.sleep(self.sleepTime)
         url=self.getUrl("/")
         self.browser.get(url)
-        sleepTime=0.2
-        time.sleep(sleepTime)
+        await asyncio.sleep(self.sleepTime)
         divs=self.browser.find_elements(By.TAG_NAME,"div")
         # get the clickable div
         div=divs[1]
         self.assertEqual("Not clicked yet",div.text)
         for i in range(5):
             div.click()
-            time.sleep(sleepTime)
+            await asyncio.sleep(self.sleepTime)
             self.assertEqual(f"I was clicked {i+1} times",div.text)
         self.browser.close()
+        await asyncio.sleep(self.sleepTime)
         
\ No newline at end of file
